@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "0.11.2"
+version = "0.11.3"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -40,7 +40,7 @@ conn_bufsize = 98304
 # This is used in rorpiter.CacheIndexable.  The number represents the
 # number of rpaths which may be stuck in buffers when moving over a
 # remote connection.
-pipeline_max_length = int(conn_bufsize / 150)*2
+pipeline_max_length = 500
 
 # True if script is running as a server
 server = None
@@ -156,9 +156,6 @@ select_mirror = None
 # object.  Access is provided to increment error counts.
 ITRB = None
 
-# Percentage of time to spend sleeping.  None means never sleep.
-sleep_ratio = None
-
 # security_level has 4 values and controls which requests from remote
 # systems will be honored.  "all" means anything goes. "read-only"
 # means that the requests must not write to disk.  "update-only" means
