@@ -57,10 +57,9 @@ def parse_cmdlineoptions(arglist):
 		  "parsable-output", "print-statistics", "quoting-char=",
 		  "remote-cmd=", "remote-schema=", "remove-older-than=",
 		  "restore-as-of=", "restrict=", "restrict-read-only=",
-		  "restrict-update-only=", "server", "sleep-ratio=",
-		  "ssh-no-compression", "terminal-verbosity=", "test-server",
-		  "verbosity=", "version", "windows-mode",
-		  "windows-time-format"])
+		  "restrict-update-only=", "server", "ssh-no-compression",
+		  "terminal-verbosity=", "test-server", "verbosity=",
+		  "version", "windows-mode", "windows-time-format"])
 	except getopt.error, e:
 		commandline_error("Bad commandline options: %s" % str(e))
 
@@ -133,8 +132,6 @@ def parse_cmdlineoptions(arglist):
 		elif opt == "-s" or opt == "--server":
 			action = "server"
 			Globals.server = 1
-		elif opt == "--sleep-ratio":
-			Globals.set_float("sleep_ratio", arg, 0, 1, inclusive=0)
 		elif opt == "--ssh-no-compression":
 			Globals.set('ssh_compression', None)
 		elif opt == "--terminal-verbosity": Log.setterm_verbosity(arg)
@@ -207,6 +204,7 @@ def take_action(rps):
 	"""Do whatever action says"""
 	if action == "server":
 		connection.PipeConnection(sys.stdin, sys.stdout).Server()
+		sys.exit(0)
 	elif action == "backup": Backup(rps[0], rps[1])
 	elif action == "restore": Restore(*rps)
 	elif action == "restore-as-of": RestoreAsOf(rps[0], rps[1])
@@ -297,6 +295,8 @@ option.""" % rpout.path)
 		except os.error:
 			Log.FatalError("Unable to create directory %s" % rpout.path)
 	if not datadir.lstat(): datadir.mkdir()
+	inc_base = datadir.append_path("increments")
+	if not inc_base.lstat(): inc_base.mkdir()
 	if Log.verbosity > 0:
 		Log.open_logfile(datadir.append("backup.log"))
 	ErrorLog.open(Time.curtimestr, compress = Globals.compression)
@@ -601,5 +601,6 @@ def checkdest_if_necessary(dest_rp):
 	"""
 	need_check = checkdest_need_check(dest_rp)
 	if need_check == 1:
-		Log("Previous backup seems to have failed, checking now.", 2)
+		Log("Previous backup seems to have failed, regressing "
+			"destination now.", 2)
 		dest_rp.conn.regress.Regress(dest_rp)
