@@ -151,7 +151,9 @@ Couldn't start up the remote connection by executing
 
 Remember that, under the default settings, rdiff-backup must be
 installed in the PATH on the remote system.  See the man page for more
-information.""" % (exception, remote_cmd))
+information on this.  This message may also be displayed if the remote
+version of rdiff-backup is quite different from the local version (%s)."""
+					   % (exception, remote_cmd, Globals.version))
 		
 	if remote_version != Globals.version:
 		Log("Warning: Local version %s does not match remote version %s."
@@ -172,8 +174,8 @@ def init_connection_routing(conn, conn_number, remote_cmd):
 
 def init_connection_settings(conn):
 	"""Tell new conn about log settings and updated globals"""
-	conn.Log.setverbosity(Log.verbosity)
-	conn.Log.setterm_verbosity(Log.term_verbosity)
+	conn.log.Log.setverbosity(Log.verbosity)
+	conn.log.Log.setterm_verbosity(Log.term_verbosity)
 	for setting_name in Globals.changed_settings:
 		conn.Globals.set(setting_name, Globals.get(setting_name))
 	FilenameMapping.set_init_quote_vals()
